@@ -6,14 +6,18 @@ import attr
 from .const import (
     CONF_MAC,
     CONF_SENSOR,
-    SENSOR_TEMPERATURE,
-    SENSOR_DEWPOINT,
-    SENSOR_PRESSURE,
-    SENSOR_PRESSUREATSEALEVEL,
+    SENSOR_AMBIENT,
     SENSOR_APPARENT_POWERUSAGE,
     SENSOR_BATTERY,
+    SENSOR_CCT,
+    SENSOR_CO2,
+    SENSOR_COLOR_BLUE,
+    SENSOR_COLOR_GREEN,
+    SENSOR_COLOR_RED,
     SENSOR_CURRENT,
+    SENSOR_DEWPOINT,
     SENSOR_DISTANCE,
+    SENSOR_ECO2,
     SENSOR_FREQUENCY,
     SENSOR_HUMIDITY,
     SENSOR_ILLUMINANCE,
@@ -29,26 +33,21 @@ from .const import (
     SENSOR_PM10,
     SENSOR_POWERFACTOR,
     SENSOR_POWERUSAGE,
-    SENSOR_TOTAL_START_TIME,
+    SENSOR_PRESSURE,
+    SENSOR_PRESSUREATSEALEVEL,
+    SENSOR_PROXIMITY,
     SENSOR_REACTIVE_POWERUSAGE,
+    SENSOR_TEMPERATURE,
     SENSOR_TODAY,
     SENSOR_TOTAL,
+    SENSOR_TOTAL_START_TIME,
+    SENSOR_TVOC,
+    SENSOR_UNIT_PRESSURE,
+    SENSOR_UNIT_TEMPERATURE,
     SENSOR_VOLTAGE,
     SENSOR_WEIGHT,
     SENSOR_YESTERDAY,
-    SENSOR_CO2,
-    SENSOR_ECO2,
-    SENSOR_TVOC,
-    SENSOR_COLOR_RED,
-    SENSOR_COLOR_GREEN,
-    SENSOR_COLOR_BLUE,
-    SENSOR_CCT,
-    SENSOR_PROXIMITY,
-    SENSOR_AMBIENT,
-    SENSOR_UNIT_PRESSURE,
-    SENSOR_UNIT_TEMPERATURE,
 )
-
 from .entity import (
     TasmotaAvailability,
     TasmotaAvailabilityConfig,
@@ -56,12 +55,12 @@ from .entity import (
     TasmotaEntityConfig,
 )
 from .utils import (
+    config_get_state_offline,
+    config_get_state_online,
     get_topic_command_status,
     get_topic_stat_status,
     get_topic_tele_sensor,
     get_topic_tele_will,
-    config_get_state_offline,
-    config_get_state_online,
     get_value_by_path,
 )
 
@@ -184,10 +183,11 @@ class TasmotaSensorConfig(TasmotaAvailabilityConfig, TasmotaEntityConfig):
             friendly_name=sensor_name,
             mac=device_config[CONF_MAC],
             platform=platform,
+            poll_payload="8",
+            poll_topic=get_topic_command_status(device_config),
             availability_topic=get_topic_tele_will(device_config),
             availability_offline=config_get_state_offline(device_config),
             availability_online=config_get_state_online(device_config),
-            poll_topic=get_topic_command_status(device_config),
             quantity=quantity,
             state_topic1=get_topic_tele_sensor(device_config),
             state_topic2=get_topic_stat_status(device_config, 8),
@@ -207,19 +207,9 @@ class TasmotaSensor(TasmotaAvailability, TasmotaEntity):
 
     def __init__(self, **kwds):
         """Initialize."""
-        self._on_state_callback = None
         self._sub_state = None
         super().__init__(**kwds)
 
-    def poll_status(self):
-        """Poll for status."""
-        payload = "8"
-        self._mqtt_client.publish_debounced(self._cfg.poll_topic, payload)
-
-    def set_on_state_callback(self, on_state_callback):
-        """Set callback for state change."""
-        self._on_state_callback = on_state_callback
-
     async def subscribe_topics(self):
         """Subscribe to topics."""
 
@@ -261,7 +251,7 @@ class TasmotaSensor(TasmotaAvailability, TasmotaEntity):
 
     @property
     def quantity(self):
-        """Return the sensors quantity (speed, mass, etc.)."""
+        """Return the sensor's quantity (speed, mass, etc.)."""
         return self._cfg.quantity
 
     @property
